@@ -1,9 +1,9 @@
 /*****
 *
-* Copyright (C) 1998 - 2003 Yoann Vandoorselaere <yoann@prelude-ids.org>
-* All Rights Reserved
+* Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 PreludeIDS Technologies. All Rights Reserved.
+* Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
-* This file is part of the Prelude program.
+* This file is part of the Prelude-LML program.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by 
@@ -24,10 +24,20 @@
 
 int file_server_get_event_fd(void);
 
-int file_server_wake_up(regex_list_t *list);
+void file_server_set_batch_mode(void);
 
-int file_server_monitor_file(const char *file);
+void file_server_set_ignore_metadata(void);
 
-void file_server_start_monitoring(regex_list_t *list);
+int file_server_wake_up(void);
 
-void file_server_set_rotation_interval_max_difference(int val);
+int file_server_monitor_file(regex_list_t *rlist, lml_log_source_t *ls);
+
+void file_server_start_monitoring(void);
+
+unsigned int file_server_get_max_rotation_time_offset(void);
+
+void file_server_set_max_rotation_time_offset(unsigned int val);
+
+unsigned int file_server_get_max_rotation_size_offset(void);
+
+void file_server_set_max_rotation_size_offset(unsigned int val);
