@@ -1,3 +1,28 @@
+/*****
+*
+* Copyright (C) 2003, 2004, 2005 PreludeIDS Technologies. All Rights Reserved.
+* Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
+*
+* This file is part of the Prelude-LML program.
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by 
+* the Free Software Foundation; either version 2, or (at your option)
+* any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; see the file COPYING.  If not, write to
+* the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+*
+*****/
+
+#include "config.h"
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -5,24 +30,23 @@
 #include <ctype.h>
 #include <sys/time.h>
 
-#include <libprelude/list.h>
+#include <libprelude/prelude.h>
 #include <libprelude/prelude-log.h>
-#include <libprelude/plugin-common.h>
-#include <libprelude/plugin-common-prv.h>
 
+#include "prelude-lml.h"
 #include "common.h"
 #include "regex.h"
-#include "log-common.h"
-#include "plugin-log-prv.h"
+#include "log-entry.h"
+#include "log-plugins.h"
 
 
-struct regex_entry {
+typedef struct {
+        prelude_list_t list;
         pcre *regex_compiled;
         pcre_extra *regex_extra;
         int options;
-        plugin_container_t *plugin;
-        struct list_head list;
-};
+        prelude_plugin_instance_t *plugin;
+} regex_entry_t;
 
 
 
@@ -36,7 +60,6 @@ static char *trim(char *str)
         wptr = rptr = str;
         
         while ( *rptr != '\0' ) {
-
                 if ( isspace((int) *rptr) ) {
                         do {
                                 rptr++;
@@ -61,7 +84,7 @@ static regex_entry_t *regex_entry_new(regex_list_t *list)
 
         new = malloc(sizeof(*new));
         if ( ! new ) {
-                log(LOG_ERR, "memory exhausted.\n");
+                prelude_log(PRELUDE_LOG_ERR, "memory exhausted.\n");
                 return NULL;
         }
 
@@ -69,7 +92,7 @@ static regex_entry_t *regex_entry_new(regex_list_t *list)
         new->regex_extra = NULL;
         new->options = 0;
 
-        list_add_tail(&new->list, list);
+        prelude_list_add_tail(list, &new->list);
 
         return new;
 }
@@ -79,7 +102,7 @@ static regex_entry_t *regex_entry_new(regex_list_t *list)
 
 static void regex_entry_delete(regex_entry_t *entry)
 {
-        list_del(&entry->list);
+        prelude_list_del(&entry->list);
 
         if ( entry->regex_compiled )
                 pcre_free(entry->regex_compiled);
@@ -93,17 +116,18 @@ static void regex_entry_delete(regex_entry_t *entry)
 
 
 
-static int regex_create_entry(regex_list_t *list, const char *filename,
-                              int line, const char *pname, const char *regex, const char *options) 
+static int regex_create_entry(regex_list_t *list, int line, const char *source,
+                              const char *pname, const char *regex, const char *options) 
 {
         int erroffset;
         pcre *compiled;
         const char *errptr;
         regex_entry_t *entry;
-
+        prelude_plugin_generic_t *plugin;
+        
         compiled = pcre_compile(regex, 0, &errptr, &erroffset, NULL);
         if ( ! compiled ) {
-                log(LOG_INFO, "%s:%d : unable to compile: %s.\n", filename, line, errptr);
+                prelude_log(PRELUDE_LOG_WARN, "%s:%d : unable to compile: %s.\n", REGEX_CONF, line, errptr);
                 return -1;
         }
         
@@ -112,22 +136,27 @@ static int regex_create_entry(regex_list_t *list, const char *filename,
                 pcre_free(compiled);
                 return -1;
         }
-        
+
         entry->regex_compiled = compiled;
         entry->regex_extra = pcre_study(entry->regex_compiled, 0, &errptr);
 
         entry->plugin = log_plugin_register(pname);
         if ( ! entry->plugin ) {
                 regex_entry_delete(entry);
-                log(LOG_INFO, "%s:%d : couldn't find plugin: %s.\n", filename, line, pname);
+                prelude_log(PRELUDE_LOG_WARN, "%s:%d : couldn't find plugin: %s.\n", REGEX_CONF, line, pname);
+                return -1;
         }
+
+        plugin = prelude_plugin_instance_get_plugin(entry->plugin);
+        prelude_log(PRELUDE_LOG_INFO, "- Monitoring %s through %s[%s]\n",
+                    source, plugin->name, prelude_plugin_instance_get_name(entry->plugin));
         
         /*
          * TBD: take care of options field
          */
         
-        dprint("[REGEX] rule found: plugin: %s - pattern: %s - options: %s\n", pname, regex, options);
-
+        prelude_log(PRELUDE_LOG_DEBUG, "[REGEX] rule found: plugin: %s - pattern: %s - options: %s\n", pname, regex, options);
+        
         return 0;
 }
 
@@ -135,30 +164,29 @@ static int regex_create_entry(regex_list_t *list, const char *filename,
 
 
 
-regex_list_t *regex_init(char *filename)
+regex_list_t *regex_init(const char *source)
 {
         FILE *fd;
         char buf[1024];
         int line = 1, ret;
         regex_list_t *conf;
-        char *name, *regex, *options;
+        char *name, *regex, *options, *file;
 
         conf = malloc(sizeof(*conf));
         if ( ! conf ) {
-                log(LOG_ERR, "memory exhausted.\n");
+                prelude_log(PRELUDE_LOG_ERR, "memory exhausted.\n");
                 return NULL;
         }
         
-        INIT_LIST_HEAD(conf);
+        prelude_list_init(conf);
 
-        fd = fopen(filename, "r");
+        fd = fopen(REGEX_CONF, "r");
         if ( ! fd ) {
-                log(LOG_ERR, "couldn't open config file %s.\n", filename);
+                prelude_log(PRELUDE_LOG_ERR, "couldn't open config file %s.\n", REGEX_CONF);
                 return NULL;
         }
 
         while ( fgets(buf, sizeof(buf), fd) ) {
-
                 trim(buf);
                 
                 if ( buf[0] == '#' || buf[0] == '\0' )
@@ -166,8 +194,19 @@ regex_list_t *regex_init(char *filename)
                          * ignore comments and empty lines
                          */
                         continue;
+
+                file = strtok(buf, " \t");
+                if ( ! file ) {
+                        line++;
+                        continue;
+                }
                 
-                name = strtok(buf, " \t");
+                if ( strcmp(file, source) != 0 && strcmp(file, "*") != 0 ) {
+                        line++;
+                        continue;
+                }
+                
+                name = strtok(NULL, " \t");
                 if ( ! name ) {
                         line++;
                         continue;
@@ -184,8 +223,8 @@ regex_list_t *regex_init(char *filename)
                         line++;
                         continue;
                 }
-                
-                ret = regex_create_entry(conf, filename, line, name, regex, options);
+
+                ret = regex_create_entry(conf, line, source, name, regex, options);
                 if ( ret < 0 )
                         continue;
                 
@@ -193,7 +232,13 @@ regex_list_t *regex_init(char *filename)
         }
         
         fclose(fd);
-    
+
+        if ( prelude_list_is_empty(conf) ) {
+                prelude_log(PRELUDE_LOG_WARN, "No plugin configured to receive %s data.\n", source);
+                free(conf);
+                return NULL;
+        }
+        
         return conf;
 }
 
@@ -203,10 +248,10 @@ regex_list_t *regex_init(char *filename)
 void regex_destroy(regex_list_t *list)
 {
         regex_entry_t *entry;
-        struct list_head *tmp, *bkp;
+        prelude_list_t *tmp, *bkp;
 
-        list_for_each_safe(tmp, bkp, list) {
-                entry = list_entry(tmp, regex_entry_t, list);
+        prelude_list_for_each_safe(list, tmp, bkp) {
+                entry = prelude_list_entry(tmp, regex_entry_t, list);
                 regex_entry_delete(entry);
         }
         
@@ -216,27 +261,25 @@ void regex_destroy(regex_list_t *list)
 
 
 
-int regex_exec(regex_list_t *list, const char *str,
-               void (*cb)(void *plugin, void *data), void *data)
+int regex_exec(regex_list_t *list,
+               void (*cb)(void *plugin, void *data), void *data,
+               const char *str, size_t len)
 {
+        prelude_list_t *tmp;
         regex_entry_t *entry;
-        struct list_head *tmp;
         int count, ovector[20 * 3];
         
-        list_for_each(tmp, list) {
-                entry = list_entry(tmp, regex_entry_t, list);
-                                
+        prelude_list_for_each(list, tmp) {
+                entry = prelude_list_entry(tmp, regex_entry_t, list);
+
                 count = pcre_exec(entry->regex_compiled, entry->regex_extra,
-                                  str, strlen(str), 0, 0, ovector, 20 * 3);
+                                  str, len, 0, 0, ovector, 20 * 3);
                 if ( count <= 0 )
                         continue;
                 
-                dprint("[REGEX] string <%s> matched - count = %d\n", str, count);
+                prelude_log_debug(10, "[REGEX] string <%s> matched - count = %d\n", str, count);
                 cb(entry->plugin, data);
         }
         
         return 0;
 }
-
-
-
